@@ -39,6 +39,7 @@
 #'
 #' @examples
 #' data(my_BBN, combined)
+#'# Run the prediction
 #' bbn.predict(bbn.model = my_BBN, priors1 = combined, boot_max=100, values=1, figure=1, font.size=5)
 #'
 #' @export
@@ -47,6 +48,7 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
   list <- list(...)
   plot.keep= list() # to display plots at the end of the function
   policyno = length(list)
+  output.list <- list()  # will store summary + plot for each scenario
 
 
   if(length(list)>12){
@@ -198,7 +200,7 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
             #print(temp2)
             #print(f)
           }
-          else if(all(post.node.calc >= 0.5) == T){  ## if all 0.5 or above, then sort by biggest first. take difference between current prob and multiply this up to increase cerinty when everything agrees
+          else if(mean(post.node.calc >= 0.5) == T){  ## if all 0.5 or above, then sort by biggest first. take difference between current prob and multiply this up to increase cerinty when everything agrees
             post.node.calc <- sort(post.node.calc, decreasing = T)
             temp2 <- post.node.calc[1]
             if(length(post.node.calc)>1){
@@ -209,7 +211,7 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
             #print(temp2)
             #print(f)
           }
-          else if(all(post.node.calc <= 0.5) == T){ ##
+          else if(mean(post.node.calc < 0.5) == T){ ##
             post.node.calc <- sort(post.node.calc, decreasing = F)
             temp2 <- post.node.calc[1]
             if(length(post.node.calc)>1){
@@ -334,6 +336,10 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
     final.output$UpperCI<-ff(final.output$UpperCI)
     final.output$UpperCI<-gg(final.output$UpperCI)
 
+
+
+
+
     p0<-ggplot(data=final.output, aes(x=name, y=Increase)) +
       geom_point(stat="identity", size=0.5) +
       geom_errorbar(aes(ymin = LowerCI, ymax = UpperCI), width=0.1) +
@@ -347,6 +353,12 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
 
     plot.keep[[policy]] <- p0
 
+    output.list[[policy]] <- list(
+      summary = final.output,
+      plot = p0
+    )
+
+
   }
 
   if(figure==1){## plot pdf figure to working directory
@@ -384,4 +396,7 @@ bbn.predict <- function(bbn.model, ..., boot_max=1, values = 1, figure = 1, font
     if(policyno==11){multiplot(plot.keep[[1]],plot.keep[[2]],plot.keep[[3]], plot.keep[[4]], plot.keep[[5]], plot.keep[[6]],plot.keep[[7]],plot.keep[[8]],plot.keep[[9]],plot.keep[[10]],plot.keep[[11]],cols=3)}
     if(policyno==12){multiplot(plot.keep[[1]],plot.keep[[2]],plot.keep[[3]], plot.keep[[4]], plot.keep[[5]], plot.keep[[6]],plot.keep[[7]],plot.keep[[8]],plot.keep[[9]],plot.keep[[10]],plot.keep[[11]], plot.keep[[12]],cols=3)}
   }
+  class(output.list) <- "bbnpredict"
+  return(invisible(output.list))
+
 }
